@@ -26,7 +26,7 @@ out <- ssa(
   method = ssa_exact(),
   sim_name = sim_name
 ) 
-autoplot.ssa(out)
+plot_ssa(out)
 
 ## ----etl----------------------------------------------------------------------
 set.seed(1)
@@ -38,7 +38,7 @@ out <- ssa(
   method = ssa_etl(tau = .03),
   sim_name = sim_name
 ) 
-autoplot.ssa(out)
+plot_ssa(out)
 
 ## ----btl----------------------------------------------------------------------
 set.seed(1)
@@ -50,5 +50,5 @@ out <- ssa(
   method = ssa_btl(mean_firings = 5),
   sim_name = sim_name
 ) 
-autoplot.ssa(out)
+plot_ssa(out)
 
